======================================
 Release notes for nitime version 0.6
======================================

Summary of changes
------------------

This is a maintenance release, to support newer versions of matplotlib and numpy.


Contributors to this release
----------------------------

The following people contributed to this release:

* Ariel Rokem
* Igor Gnatenko
* Yaroslav Halchenko

.. Note::

   This list was generated using::

   git log --pretty=format:"* %aN" rel/0.5... | sort | uniq

   Please let us know if you should appear on this list and do not, so that we
   can add your name in future release notes.


Detailed stats from the github repository
-----------------------------------------

GitHub stats for the last  604 days.
We closed a total of 15 issues, 6 pull requests and 9 regular
issues; this is the full list (generated with the script
`tools/github_stats.py`):

Pull Requests (6):

* :ghissue:`139`: Testing fixes
* :ghissue:`138`: TST: Update Travis config, add appveyor config.
* :ghissue:`134`: test_viz: import networkx instead of nx
* :ghissue:`135`: BF: Newer numpy can't deal with the type coercion that comes with inplace division
* :ghissue:`130`: RF: Modernize this call to Matplotlib to address DeprecationWarning
* :ghissue:`128`: BF(PY2.6): use sys.version_info as unnamed tuple

Issues (9):

* :ghissue:`139`: Testing fixes
* :ghissue:`138`: TST: Update Travis config, add appveyor config.
* :ghissue:`134`: test_viz: import networkx instead of nx
* :ghissue:`135`: BF: Newer numpy can't deal with the type coercion that comes with inp…
* :ghissue:`132`: RuntimeWarning: Breaking due to iterative meltdown in nitime.utils.adaptive_weights.
* :ghissue:`129`: nitime.viz import error, ImportError: 'No module named mpl_toolkits.axes_grid'
* :ghissue:`130`: RF: Modernize this call to Matplotlib to address DeprecationWarning
* :ghissue:`131`: Multi-taper coherence estimation with two signals of different length?
* :ghissue:`128`: BF(PY2.6): use sys.version_info as unnamed tuple
